@@ -1,7 +1,7 @@
 /*
 
-Copyright (C) 2004, 2005, 2006, 2007 David Bateman
-Copyright (C) 1998, 1999, 2000, 2001, 2002, 2003, 2004 Andy Adler
+Copyright (C) 2004-2011 David Bateman
+Copyright (C) 1998-2004 Andy Adler
 
 This file is part of Octave.
 
@@ -43,7 +43,7 @@ octave_sparse_params::instance_ok (void)
   if (! instance)
     {
       (*current_liboctave_error_handler)
-	("unable to create octave_sparse_params object!");
+        ("unable to create octave_sparse_params object!");
 
       retval = false;
     }
@@ -111,37 +111,39 @@ octave_sparse_params::print_info (std::ostream& os, const std::string& prefix)
 void
 octave_sparse_params::do_defaults (void)
 {
-  params(0) = 0;    // spumoni
-  params(1) = 1;    // ths_rel
-  params(2) = 1;    // ths_abs
-  params(3) = 0;    // exact_d
-  params(4) = 3;    // supernd
-  params(5) = 3;    // rreduce
-  params(6) = 0.5;  // wh_frac
-  params(7) = 1;    // autommd
-  params(8) = 1;    // autoamd
-  params(9) = 0.1;  // piv_tol
-  params(10) = 0.5; // bandden
-  params(11) = 1;   // umfpack
+  params(0) = 0;      // spumoni
+  params(1) = 1;      // ths_rel
+  params(2) = 1;      // ths_abs
+  params(3) = 0;      // exact_d
+  params(4) = 3;      // supernd
+  params(5) = 3;      // rreduce
+  params(6) = 0.5;    // wh_frac
+  params(7) = 1;      // autommd
+  params(8) = 1;      // autoamd
+  params(9) = 0.1;    // piv_tol
+  params(10) = 0.5;   // bandden
+  params(11) = 1;     // umfpack
+  params(12) = 0.001; // sym_tol
 }
 
 void
 octave_sparse_params::do_tight (void)
 {
-  params(0) = 0;    // spumoni
-  params(1) = 1;    // ths_rel
-  params(2) = 0;    // ths_abs
-  params(3) = 1;    // exact_d
-  params(4) = 1;    // supernd
-  params(5) = 1;    // rreduce
-  params(6) = 0.5;  // wh_frac
-  params(7) = 1;    // autommd
-  params(8) = 1;    // autoamd
-  params(9) = 0.1;  // piv_tol
-  params(10) = 0.5; // bandden
-  params(11) = 1;   // umfpack
+  params(0) = 0;      // spumoni
+  params(1) = 1;      // ths_rel
+  params(2) = 0;      // ths_abs
+  params(3) = 1;      // exact_d
+  params(4) = 1;      // supernd
+  params(5) = 1;      // rreduce
+  params(6) = 0.5;    // wh_frac
+  params(7) = 1;      // autommd
+  params(8) = 1;      // autoamd
+  params(9) = 0.1;    // piv_tol
+  params(10) = 0.5;   // bandden
+  params(11) = 1;     // umfpack
+  params(12) = 0.001; // sym_tol
 }
-  
+
 void
 octave_sparse_params::init_keys (void)
 {
@@ -157,6 +159,7 @@ octave_sparse_params::init_keys (void)
   keys(9) = "piv_tol";
   keys(10) = "bandden";
   keys(11) = "umfpack";
+  keys(12) = "sym_tol";
 }
 
 double
@@ -173,14 +176,14 @@ octave_sparse_params::do_set_vals (const NDArray& vals)
   if (len > OCTAVE_SPARSE_CONTROLS_SIZE)
     {
       (*current_liboctave_error_handler)
-	("octave_sparse_params::do_set_vals: too many values");
+        ("octave_sparse_params::do_set_vals: too many values");
 
       return false;
     }
   else
     {
       for (int i = 0; i < len; i++)
-	params(i) = vals(i);
+        params(i) = vals(i);
 
       return true;
     }
@@ -192,10 +195,10 @@ octave_sparse_params::do_set_key (const std::string& key, const double& val)
   for (int i = 0; i < OCTAVE_SPARSE_CONTROLS_SIZE; i++)
     {
       if (keys (i) == key)
-	{
-	  params(i) = val;
-	  return true;
-	}
+        {
+          params(i) = val;
+          return true;
+        }
     }
 
   return false;
@@ -207,7 +210,7 @@ octave_sparse_params::do_get_key (const std::string& key)
   for (int i = 0; i < OCTAVE_SPARSE_CONTROLS_SIZE; i++)
     {
       if (keys (i) == key)
-	return params(i);
+        return params(i);
     }
 
   return octave_NaN;
@@ -215,14 +218,8 @@ octave_sparse_params::do_get_key (const std::string& key)
 
 void
 octave_sparse_params::do_print_info (std::ostream& os,
-				     const std::string& prefix) const
+                                     const std::string& prefix) const
 {
   for (int i = 0; i < OCTAVE_SPARSE_CONTROLS_SIZE; i++)
     os << prefix << keys(i) << ": " << params(i) << "\n";
 }
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
