@@ -1,11 +1,11 @@
-## Copyright (C) 2003 John W. Eaton
+## Copyright (C) 2003-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,13 +13,15 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {filename = } tempname ()
+## @deftypefn  {Function File} {} tempname ()
+## @deftypefnx {Function File} {} tempname (@var{dir})
+## @deftypefnx {Function File} {} tempname (@var{dir}, @var{prefix})
 ## This function is an alias for @code{tmpnam}.
+## @seealso{tmpnam}
 ## @end deftypefn
 
 function filename = tempname (varargin)
