@@ -1,11 +1,11 @@
-## Copyright (C) 2005 John W. Eaton
+## Copyright (C) 2005-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
 ## Octave is free software; you can redistribute it and/or modify it
 ## under the terms of the GNU General Public License as published by
-## the Free Software Foundation; either version 2, or (at your option)
-## any later version.
+## the Free Software Foundation; either version 3 of the License, or (at
+## your option) any later version.
 ##
 ## Octave is distributed in the hope that it will be useful, but
 ## WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -13,13 +13,28 @@
 ## General Public License for more details.
 ##
 ## You should have received a copy of the GNU General Public License
-## along with Octave; see the file COPYING.  If not, write to the Free
-## Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-## 02110-1301, USA.
+## along with Octave; see the file COPYING.  If not, see
+## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} gcf ()
-## Return the current figure handle.
+## Return the current figure handle.  If a figure does not exist, create
+## one and return its handle.  The handle may then be used to examine or
+## set properties of the figure.  For example,
+##
+## @example
+## @group
+## fplot (@@sin, [-10, 10]);
+## fig = gcf ();
+## set (fig, "visible", "off");
+## @end group
+## @end example
+##
+## @noindent
+## plots a sine wave, finds the handle of the current figure, and then
+## makes that figure invisible.  Setting the visible property of the
+## figure to @code{"on"} will cause it to be displayed again.
+## @seealso{get, set}
 ## @end deftypefn
 
 ## Author: jwe, Bill Denney
