@@ -1,4 +1,4 @@
-## Copyright (C) 1996, 2006, 2007, 2008, 2009 John W. Eaton
+## Copyright (C) 1996-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -58,7 +58,7 @@
 ## @example
 ## plot3 (@var{x1}, @var{y1}, @var{z1}, @var{x2}, @var{y2}, @var{z2}, @dots{})
 ## @end example
-## 
+##
 ## @noindent
 ## in which each set of three arguments is treated as a separate line or
 ## set of lines in three dimensions.
@@ -95,7 +95,8 @@ function retval = plot3 (varargin)
   property_set = 0;
   fmt_set = 0;
   properties = {};
-
+  tlgnd = {};
+  hlgnd = [];
   idx = 0;
 
   ## Gather arguments, decode format, and plot lines.
@@ -112,80 +113,84 @@ function retval = plot3 (varargin)
 
     if (ischar (new))
       if (! z_set)
-	if (! y_set)
-	  if (! x_set)
-	    error ("plot3: needs x, [ y, [ z ] ]");
-	  else
-	    z = imag (x);
-	    y = real (x);
-	    y_set = 1;
-	    z_set = 1;
-	    if (rows(x) > 1)
-	      x = repmat ((1:rows(x))', 1, columns(x));
-	    else
-	      x = 1:columns(x);
-	    endif
-	  endif
-	else
-	  z = imag (y);
-	  y = real (y);
-	  z_set = 1;
-	endif
+        if (! y_set)
+          if (! x_set)
+            error ("plot3: needs x, [ y, [ z ] ]");
+          else
+            z = imag (x);
+            y = real (x);
+            y_set = 1;
+            z_set = 1;
+            if (rows(x) > 1)
+              x = repmat ((1:rows(x))', 1, columns(x));
+            else
+              x = 1:columns(x);
+            endif
+          endif
+        else
+          z = imag (y);
+          y = real (y);
+          z_set = 1;
+        endif
       endif
 
       if (! fmt_set)
-	[options, valid] = __pltopt__ ("plot3", new, false);
-	if (! valid)
-	  properties = [properties, new_cell];
-	  property_set = 1;
-	  continue;
-	else
-	  fmt_set = 1;
-	  while (arg < nargin && ischar (varargin{arg+1}))
-	    if (nargin - arg < 2)
-	      error ("plot3: properties must appear followed by a value");
-	    endif
-	    properties = [properties, varargin(arg:arg+1)];
-	    arg += 2;
-	  endwhile
-	endif
+        [options, valid] = __pltopt__ ("plot3", new, false);
+        if (! valid)
+          properties = [properties, new_cell];
+          property_set = 1;
+          continue;
+        else
+          fmt_set = 1;
+          while (arg < nargin && ischar (varargin{arg+1}))
+            if (nargin - arg < 2)
+              error ("plot3: properties must appear followed by a value");
+            endif
+            properties = [properties, varargin(arg+1:arg+2)];
+            arg += 2;
+          endwhile
+        endif
       else
-	properties = [properties, new_cell];
-	property_set = 1;
-	continue;
+        properties = [properties, new_cell];
+        property_set = 1;
+        continue;
       endif
 
       if (isvector (x) && isvector (y))
-	if (isvector (z))
-	  x = x(:);
-	  y = y(:);
-	  z = z(:);
-	elseif (length (x) == rows (z) && length (y) == columns (z))
-	  [x, y] = meshgrid (x, y);
-	else
-	  error ("plot3: [length(x), length(y)] must match size(z)");
-	endif
+        if (isvector (z))
+          x = x(:);
+          y = y(:);
+          z = z(:);
+        elseif (length (x) == rows (z) && length (y) == columns (z))
+          [x, y] = meshgrid (x, y);
+        else
+          error ("plot3: [length(x), length(y)] must match size(z)");
+        endif
       endif
 
       if (! size_equal (x, y, z))
-	error ("plot3: x, y, and z must have the same shape");
-      endif
-
-      key = options.key;
-      if (! isempty (key))
-	set (gca (), "key", "on");
+        error ("plot3: x, y, and z must have the same shape");
       endif
 
       for i = 1 : columns (x)
-	color = options.color;
-	if (isempty (options.color))
-	  color = __next_line_color__ ();
-	endif
+        linestyle = options.linestyle;
+        marker = options.marker;
+        if (isempty (marker) && isempty (linestyle))
+           [linestyle, marker] = __next_line_style__ ();
+        endif
+        color = options.color;
+        if (isempty (color))
+          color = __next_line_color__ ();
+        endif
 
-	tmp(++idx) = line (x(:, i), y(:, i), z(:, i),  "keylabel", key,
-			   "color", color,
-			   "linestyle", options.linestyle,
-			   "marker", options.marker, properties{:});
+        tmp(++idx) = line (x(:, i), y(:, i), z(:, i),
+                           "color", color, "linestyle", linestyle,
+                           "marker", marker, properties{:});
+        key = options.key;
+        if (! isempty (key))
+          hlgnd = [hlgnd, tmp(idx)];
+          tlgnd = {tlgnd{:}, key};
+        endif
       endfor
 
       x_set = 0;
@@ -204,37 +209,41 @@ function retval = plot3 (varargin)
       z_set = 1;
     else
       if (isvector (x) && isvector (y))
-	if (isvector (z))
-	  x = x(:);
-	  y = y(:);
-	  z = z(:);
-	elseif (length (x) == rows (z) && length (y) == columns (z))
-	  [x, y] = meshgrid (x, y);
-	else
-	  error ("plot3: [length(x), length(y)] must match size(z)");
-	endif
+        if (isvector (z))
+          x = x(:);
+          y = y(:);
+          z = z(:);
+        elseif (length (x) == rows (z) && length (y) == columns (z))
+          [x, y] = meshgrid (x, y);
+        else
+          error ("plot3: [length(x), length(y)] must match size(z)");
+        endif
       endif
 
       if (! size_equal (x, y, z))
-	error ("plot3: x, y, and z must have the same shape");
+        error ("plot3: x, y, and z must have the same shape");
       endif
 
       options =  __default_plot_options__ ();
-      key = options.key;
-      if (! isempty (key))
-	set (gca (), "key", "on");
-      endif
-
       for i = 1 : columns (x)
-	color = options.color;
-	if (isempty (color))
-	  color = __next_line_color__ ();
-	endif
+        linestyle = options.linestyle;
+        marker = options.marker;
+        if (isempty (marker) && isempty (linestyle))
+           [linestyle, marker] = __next_line_style__ ();
+        endif
+        color = options.color;
+        if (isempty (color))
+          color = __next_line_color__ ();
+        endif
 
-	tmp(++idx) = line (x(:, i), y(:, i), z(:, i),  "keylabel", key,
-			   "color", color,
-			   "linestyle", options.linestyle,
-			   "marker", options.marker, properties{:});
+        tmp(++idx) = line (x(:, i), y(:, i), z(:, i),
+                           "color", color, "linestyle", linestyle,
+                           "marker", marker, properties{:});
+        key = options.key;
+        if (! isempty (key))
+          hlgnd = [hlgnd, tmp(idx)];
+          tlgnd = {tlgnd{:}, key};
+        endif
       endfor
 
       x = new;
@@ -255,9 +264,9 @@ function retval = plot3 (varargin)
   if (x_set)
     if (y_set)
       if (! z_set)
-	z = imag (y);
-	y = real (y);
-	z_set = 1;
+        z = imag (y);
+        y = real (y);
+        z_set = 1;
       endif
     else
       z = imag (x);
@@ -265,21 +274,21 @@ function retval = plot3 (varargin)
       y_set = 1;
       z_set = 1;
       if (rows (x) > 1)
-	x = repmat ((1:rows (x))', 1, columns(x));
+        x = repmat ((1:rows (x))', 1, columns(x));
       else
-	x = 1:columns(x);
+        x = 1:columns(x);
       endif
     endif
 
     if (isvector (x) && isvector (y))
       if (isvector (z))
-	x = x(:);
-	y = y(:);
-	z = z(:);
+        x = x(:);
+        y = y(:);
+        z = z(:);
       elseif (length (x) == rows (z) && length (y) == columns (z))
-	[x, y] = meshgrid (x, y);
+        [x, y] = meshgrid (x, y);
       else
-	error ("plot3: [length(x), length(y)] must match size(z)");
+        error ("plot3: [length(x), length(y)] must match size(z)");
       endif
     endif
 
@@ -288,24 +297,33 @@ function retval = plot3 (varargin)
     endif
 
     options =  __default_plot_options__ ();
-    key = options.key;
-    if (! isempty (key))
-      set (gca (), "key", "on");
-    endif
 
     for i = 1 : columns (x)
+      linestyle = options.linestyle;
+      marker = options.marker;
+      if (isempty (marker) && isempty (linestyle))
+        [linestyle, marker] = __next_line_style__ ();
+      endif
       color = options.color;
       if (isempty (color))
-	color = __next_line_color__ ();
+        color = __next_line_color__ ();
       endif
 
-      tmp(++idx) = line (x(:, i), y(:, i), z(:, i),  "keylabel", key, 
-			 "color", color,
-			 "linestyle", options.linestyle,
-			 "marker", options.marker, properties{:});
+      tmp(++idx) = line (x(:, i), y(:, i), z(:, i),
+                         "color", color, "linestyle", linestyle,
+                         "marker", marker, properties{:});
+      key = options.key;
+      if (! isempty (key))
+        hlgnd = [hlgnd, tmp(idx)];
+        tlgnd = {tlgnd{:}, key};
+      endif
     endfor
   endif
 
+  if (!isempty (hlgnd))
+    legend (gca(), hlgnd, tlgnd);
+  endif
+
   set (gca (), "view", [-37.5, 30]);
 
   if (nargout > 0 && idx > 0)
