@@ -1,4 +1,4 @@
-## Copyright (C) 2004, 2005, 2006, 2007 Paul Kienzle
+## Copyright (C) 2004-2011 Paul Kienzle
 ##
 ## This file is part of Octave.
 ##
@@ -20,14 +20,14 @@
 ## public domain.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} sprandn (@var{m}, @var{n}, @var{d})
+## @deftypefn  {Function File} {} sprandn (@var{m}, @var{n}, @var{d})
 ## @deftypefnx {Function File} {} sprandn (@var{s})
-## Generate a random sparse matrix. The size of the matrix will be
+## Generate a random sparse matrix.  The size of the matrix will be
 ## @var{m} by @var{n}, with a density of values given by @var{d}.
 ## @var{d} should be between 0 and 1. Values will be normally
 ## distributed with mean of zero and variance 1.
 ##
-## Note: sometimes the actual density  may be a bit smaller than @var{d}. 
+## Note: sometimes the actual density may be a bit smaller than @var{d}.
 ## This is unlikely to happen for large really sparse matrices.
 ##
 ## If called with a single matrix argument, a random sparse matrix is
@@ -39,12 +39,13 @@
 
 function S = sprandn (m, n, d)
   if (nargin == 1)
-    [i, j, v, nr, nc] = spfind (m);
+    [i, j, v] = find (m);
+    [nr, nc] = size (m);
     S = sparse (i, j, randn (size (v)), nr, nc);
   elseif (nargin == 3)
     mn = m*n;
     k = round (d*mn);
-    idx = unique (fix (rand (min (k*1.01, k+10), 1) * mn)) + 1; 
+    idx = unique (fix (rand (min (k*1.01, k+10), 1) * mn)) + 1;
     ## idx contains random numbers in [1,mn]
     ## generate 1% or 10 more random values than necessary in order to
     ## reduce the probability that there are less than k distinct
