@@ -1,5 +1,4 @@
-## Copyright (C) 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000, 2004,
-##               2005, 2006, 2007, 2008, 2009 John W. Eaton
+## Copyright (C) 1993-2011 John W. Eaton
 ##
 ## This file is part of Octave.
 ##
@@ -19,14 +18,8 @@
 
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} hilb (@var{n})
-## Return the Hilbert matrix of order @var{n}.  The
-## @tex
-## $i,\,j$
-## @end tex
-## @ifnottex
-## i, j
-## @end ifnottex
-## element of a Hilbert matrix is defined as
+## Return the Hilbert matrix of order @var{n}.  The @math{i,j} element
+## of a Hilbert matrix is defined as
 ## @tex
 ## $$
 ## H (i, j) = {1 \over (i + j - 1)}
@@ -37,8 +30,24 @@
 ## @example
 ## H (i, j) = 1 / (i + j - 1)
 ## @end example
+##
 ## @end ifnottex
-## @seealso{hankel, vander, sylvester_matrix, invhilb, toeplitz}
+##
+## Hilbert matrices are close to being singular which make them difficult to
+## invert with numerical routines.
+## Comparing the condition number of a random matrix 5x5 matrix with that of
+## a Hilbert matrix of order 5 reveals just how difficult the problem is.
+##
+## @example
+## @group
+## cond (rand (5))
+##     @result{} 14.392
+## cond (hilb (5))
+##     @result{} 4.7661e+05
+## @end group
+## @end example
+##
+## @seealso{invhilb}
 ## @end deftypefn
 
 ## Author: jwe
