@@ -1,5 +1,4 @@
-## Copyright (C) 1995, 1996, 1997, 1998, 2000, 2002, 2003, 2004, 2005,
-##               2006, 2007 Kurt Hornik
+## Copyright (C) 1995-2011 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -18,13 +17,17 @@
 ## <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @deftypefn {Function File} {} iqr (@var{x}, @var{dim})
-## If @var{x} is a vector, return the interquartile range, i.e., the
-## difference between the upper and lower quartile, of the input data.
+## @deftypefn  {Function File} {} iqr (@var{x})
+## @deftypefnx {Function File} {} iqr (@var{x}, @var{dim})
+## Return the interquartile range, i.e., the difference between the upper
+## and lower quartile of the input data.  If @var{x} is a matrix, do the
+## above for first non-singleton dimension of @var{x}.
 ##
-## If @var{x} is a matrix, do the above for first non singleton
-## dimension of @var{x}. If the option @var{dim} argument is given,
-## then operate along this dimension.
+## If the optional argument @var{dim} is given, operate along this dimension.
+##
+## As a measure of dispersion, the interquartile range is less affected by
+## outliers than either @code{range} or @code{std}.
+## @seealso{range, std}
 ## @end deftypefn
 
 ## Author KH <Kurt.Hornik@wu-wien.ac.at>
@@ -36,27 +39,27 @@ function y = iqr (x, dim)
     print_usage ();
   endif
 
+  if (!(ismatrix (x) && isnumeric (x)) || isscalar(x))
+    error ("iqr: X must be a numeric vector or matrix");
+  endif
+
   nd = ndims (x);
   sz = size (x);
   nel = numel (x);
   if (nargin != 2)
     ## Find the first non-singleton dimension.
-    dim  = 1;
-    while (dim < nd + 1 && sz(dim) == 1)
-      dim = dim + 1;
-    endwhile
-    if (dim > nd)
+    dim = find (sz > 1, 1);
+    if (isempty (dim))
       dim = 1;
     endif
   else
-    if (! (isscalar (dim) && dim == round (dim))
-	&& dim > 0
-	&& dim < (nd + 1))
-      error ("iqr: dim must be an integer and valid dimension");
+    if (!(isscalar (dim) && dim == fix (dim))
+        || !(1 <= dim && dim <= nd))
+      error ("iqr: DIM must be an integer and a valid dimension");
     endif
   endif
 
-  ## This code is a bit heavy, but is needed until empirical_inv 
+  ## This code is a bit heavy, but is needed until empirical_inv
   ## takes other than vector arguments.
   c = sz(dim);
   sz(dim) = 1;
@@ -76,3 +79,16 @@ function y = iqr (x, dim)
   endfor
 
 endfunction
+
+%!assert (iqr (1:101), 50);
+
+%%!test
+%%! x = [1:100];
+%%! n = iqr (x, 0:10);
+%%! assert (n, [repmat(100, 1, 10), 1]);
+
+%!error iqr ();
+%!error iqr (1, 2, 3);
+%!error iqr (1);
+%!error iqr ([true, true]);
+%!error iqr (1:10, 3);
