@@ -19,8 +19,10 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} unidinv (@var{x}, @var{v})
 ## For each component of @var{x}, compute the quantile (the inverse of
-## the CDF) at @var{x} of the univariate discrete distribution which assumes the
-## values in @var{v} with equal probability
+## the CDF) at @var{x} of the discrete uniform distribution which assumes the
+## values in @var{v} with equal probability.
+## If @var{v} is a scalar then @code{1/@var{v}} is the probability of a
+## single element.
 ## @end deftypefn
 
 function inv = unidinv (x, v)
