@@ -1,5 +1,4 @@
-## Copyright (C) 1995, 1996, 1997, 1998, 2000, 2002, 2005, 2006, 2007
-##               Kurt Hornik
+## Copyright (C) 1995-2011 Kurt Hornik
 ##
 ## This file is part of Octave.
 ##
@@ -27,12 +26,12 @@
 ## @code{">"} (greater than 0), or @code{"<"} (less than 0).  The
 ## default is the two-sided case.
 ##
-## The optional argument string @var{method} specifies on which
-## correlation coefficient the test should be based.  If @var{method} is
+## The optional argument string @var{method} specifies which
+## correlation coefficient to use for testing.  If @var{method} is
 ## @code{"pearson"} (default), the (usual) Pearson's product moment
 ## correlation coefficient is used.  In this case, the data should come
 ## from a bivariate normal distribution.  Otherwise, the other two
-## methods offer nonparametric alternatives. If @var{method} is
+## methods offer nonparametric alternatives.  If @var{method} is
 ## @code{"kendall"}, then Kendall's rank correlation tau is used.  If
 ## @var{method} is @code{"spearman"}, then Spearman's rank correlation
 ## rho is used.  Only the first character is necessary.
@@ -42,14 +41,19 @@
 ## @table @var
 ## @item pval
 ## The p-value of the test.
+##
 ## @item stat
 ## The value of the test statistic.
+##
 ## @item dist
 ## The distribution of the test statistic.
+##
 ## @item params
 ## The parameters of the null distribution of the test statistic.
+##
 ## @item alternative
 ## The alternative hypothesis.
+##
 ## @item method
 ## The method used for testing.
 ## @end table
@@ -61,68 +65,68 @@
 ## Adapted-by: KH <Kurt.Hornik@wu-wien.ac.at>
 ## Description: Test for zero correlation
 
-function t = cor_test (X, Y, ALTERNATIVE, METHOD)
+function t = cor_test (x, y, alt, method)
 
   if ((nargin < 2) || (nargin > 4))
     print_usage ();
   endif
 
-  if (!isvector (X) || !isvector (Y) || length (X) != length (Y))
-    error ("cor_test: X and Y must be vectors of the same length")
+  if (!isvector (x) || !isvector (y) || length (x) != length (y))
+    error ("cor_test: X and Y must be vectors of the same length");
   endif
 
   if (nargin < 3)
-    ALTERNATIVE = "!=";
-  elseif (! ischar (ALTERNATIVE))
-    error ("cor_test: ALTERNATIVE must be a string");
+    alt = "!=";
+  elseif (! ischar (alt))
+    error ("cor_test: ALT must be a string");
   endif
 
   if (nargin < 4)
-    METHOD = "pearson";
-  elseif (! ischar (METHOD))
+    method = "pearson";
+  elseif (! ischar (method))
     error ("cor_test: METHOD must be a string");
   endif
 
-  n = length (X);
-  m = METHOD (1);
+  n = length (x);
+  m = method (1);
 
   if (m == "p")
-    r = cor (X, Y);
+    r = cor (x, y);
     df = n - 2;
     t.method = "Pearson's product moment correlation";
     t.params = df;
     t.stat = sqrt (df) .* r / sqrt (1 - r.^2);
     t.dist = "t";
-    cdf  = t_cdf (t.stat, df);
+    cdf  = tcdf (t.stat, df);
   elseif (m == "k")
-    tau = kendall (X, Y);
+    tau = kendall (x, y);
     t.method = "Kendall's rank correlation tau";
     t.params = [];
     t.stat = tau / sqrt ((2 * (2*n+5)) / (9*n*(n-1)));
     t.dist = "stdnormal";
     cdf = stdnormal_cdf (t.stat);
   elseif (m == "s")
-    rho = spearman (X, Y);
+    rho = spearman (x, y);
     t.method = "Spearman's rank correlation rho";
     t.params = [];
     t.stat = sqrt (n-1) * (rho - 6/(n^3-n));
     t.dist = "stdnormal";
     cdf = stdnormal_cdf (t.stat);
   else
-    error ("cor_test: method `%s' not recognized", METHOD)
+    error ("cor_test: METHOD `%s' not recognized", method);
   endif
 
-  if (strcmp (ALTERNATIVE, "!=") || strcmp (ALTERNATIVE, "<>"))
+  if (strcmp (alt, "!=") || strcmp (alt, "<>"))
     t.pval = 2 * min (cdf, 1 - cdf);
-  elseif (strcmp (ALTERNATIVE, ">"))
+  elseif (strcmp (alt, ">"))
     t.pval = 1 - cdf;
-  elseif (strcmp (ALTERNATIVE, "<"))
+  elseif (strcmp (alt, "<"))
     t.pval = cdf;
   else
-    error ("cor_test: alternative `%s' not recognized", ALTERNATIVE);
+    error ("cor_test: alternative `%s' not recognized", alt);
   endif
 
-  t.alternative = ALTERNATIVE;
+  t.alternative = alt;
 
   if (nargout == 0)
     printf ("pval: %g\n", t.pval);
