@@ -1,7 +1,6 @@
 /*
 
-Copyright (C) 1996, 1997, 1999, 2000, 2002, 2003, 2005, 2006, 2007
-              John W. Eaton
+Copyright (C) 1996-2011 John W. Eaton
 
 This file is part of Octave.
 
@@ -27,9 +26,7 @@ along with Octave; see the file COPYING.  If not, see
 
 #include <string>
 
-#ifdef HAVE_SYS_TYPES_H
 #include <sys/types.h>
-#endif
 
 #include "oct-passwd.h"
 
@@ -50,7 +47,7 @@ mk_pw_map (const octave_passwd& pw)
 
   if (pw)
     {
-      Octave_map m;
+      octave_scalar_map m;
 
       m.assign ("name", pw.name ());
       m.assign ("passwd", pw.passwd ());
@@ -70,9 +67,9 @@ mk_pw_map (const octave_passwd& pw)
 
 DEFUN_DLD (getpwent, args, ,
  "-*- texinfo -*-\n\
-@deftypefn {Loadable Function} {@var{pw_struct} = } getpwent ()\n\
+@deftypefn {Loadable Function} {@var{pw_struct} =} getpwent ()\n\
 Return a structure containing an entry from the password database,\n\
-opening it if necessary. Once the end of the data has been reached,\n\
+opening it if necessary.  Once the end of the data has been reached,\n\
 @code{getpwent} returns 0.\n\
 @end deftypefn")
 {
@@ -98,7 +95,7 @@ opening it if necessary. Once the end of the data has been reached,\n\
 
 DEFUN_DLD (getpwuid, args, ,
   "-*- texinfo -*-\n\
-@deftypefn {Loadable Function} {@var{pw_struct} = } getpwuid (@var{uid}).\n\
+@deftypefn {Loadable Function} {@var{pw_struct} =} getpwuid (@var{uid}).\n\
 Return a structure containing the first entry from the password database\n\
 with the user ID @var{uid}.  If the user ID does not exist in the\n\
 database, @code{getpwuid} returns 0.\n\
@@ -116,19 +113,19 @@ database, @code{getpwuid} returns 0.\n\
       double dval = args(0).double_value ();
 
       if (! error_state)
-	{
-	  if (D_NINT (dval) == dval)
-	    {
-	      uid_t uid = static_cast<uid_t> (dval);
+        {
+          if (D_NINT (dval) == dval)
+            {
+              uid_t uid = static_cast<uid_t> (dval);
 
-	      std::string msg;
+              std::string msg;
 
-	      retval(0) = mk_pw_map (octave_passwd::getpwuid (uid, msg));
-	      retval(1) = msg;
-	    }
-	  else
-	    error ("getpwuid: argument must be an integer");
-	}
+              retval(0) = mk_pw_map (octave_passwd::getpwuid (uid, msg));
+              retval(1) = msg;
+            }
+          else
+            error ("getpwuid: UID must be an integer");
+        }
     }
   else
     print_usage ();
@@ -138,7 +135,7 @@ database, @code{getpwuid} returns 0.\n\
 
 DEFUN_DLD (getpwnam, args, ,
   "-*- texinfo -*-\n\
-@deftypefn {Loadable Function} {@var{pw_struct} = } getpwnam (@var{name})\n\
+@deftypefn {Loadable Function} {@var{pw_struct} =} getpwnam (@var{name})\n\
 Return a structure containing the first entry from the password database\n\
 with the user name @var{name}.  If the user name does not exist in the\n\
 database, @code{getpwname} returns 0.\n\
@@ -156,12 +153,12 @@ database, @code{getpwname} returns 0.\n\
       std::string s = args(0).string_value ();
 
       if (! error_state)
-	{
-	  std::string msg;
+        {
+          std::string msg;
 
-	  retval(0) = mk_pw_map (octave_passwd::getpwnam (s, msg));
-	  retval(1) = msg;
-	}
+          retval(0) = mk_pw_map (octave_passwd::getpwnam (s, msg));
+          retval(1) = msg;
+        }
     }
   else
     print_usage ();
@@ -220,9 +217,3 @@ Close the password database.\n\
 
   return retval;
 }
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
