@@ -1,7 +1,6 @@
 /*
 
-Copyright (C) 1993, 1994, 1995, 1996, 1997, 2000, 2002, 2003, 2005,
-              2006, 2007 John W. Eaton
+Copyright (C) 1993-2011 John W. Eaton
 
 This file is part of Octave.
 
@@ -65,7 +64,7 @@ void
 gripe_nonconformant (octave_idx_type r1, octave_idx_type c1, octave_idx_type r2, octave_idx_type c2)
 {
   error ("nonconformant matrices (op1 is %dx%d, op2 is %dx%d)",
-	 r1, c1, r2, c2);
+         r1, c1, r2, c2);
 }
 
 void
@@ -148,13 +147,20 @@ gripe_wrong_type_arg (const char *name, const std::string& s, bool is_error)
 
 void
 gripe_wrong_type_arg (const char *name, const octave_value& tc,
-		      bool is_error)
+                      bool is_error)
 {
   std::string type = tc.type_name ();
 
   gripe_wrong_type_arg (name, type, is_error);
 }
 
+void
+gripe_wrong_type_arg (const std::string& name, const octave_value& tc,
+                      bool is_error)
+{
+  gripe_wrong_type_arg (name.c_str (), tc, is_error);
+}
+
 void
 gripe_wrong_type_arg_for_unary_op (const octave_value& op)
 {
@@ -177,11 +183,11 @@ gripe_implicit_conversion (const char *id, const char *from, const char *to)
 
 void
 gripe_implicit_conversion (const std::string& id,
-			   const std::string& from, const std::string& to)
+                           const std::string& from, const std::string& to)
 {
   warning_with_id (id.c_str (),
-		   "implicit conversion from %s to %s",
-		   from.c_str (), to.c_str ());
+                   "implicit conversion from %s to %s",
+                   from.c_str (), to.c_str ());
 }
 
 void
@@ -190,15 +196,43 @@ gripe_divide_by_zero (void)
   warning_with_id ("Octave:divide-by-zero", "division by zero");
 }
 
-extern void
+void
 gripe_logical_conversion (void)
 {
   warning_with_id ("Octave:logical-conversion",
-		   "value not equal to 1 or 0 converted to logical 1");
+                   "value not equal to 1 or 0 converted to logical 1");
 }
 
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
+void
+gripe_library_execution_error (void)
+{
+  octave_exception_state = octave_no_exception;
+
+  if (! error_state)
+    error ("caught execution error in library function");
+}
+
+void
+gripe_invalid_inquiry_subscript (void)
+{
+  error ("invalid dimension inquiry of a non-existent value");
+}
+
+void
+gripe_indexed_cs_list (void)
+{
+  error ("a cs-list cannot be further indexed");
+}
+
+void
+gripe_nonbraced_cs_list_assignment (void)
+{
+  error ("invalid assignment to cs-list outside multiple assignment");
+}
+
+void
+gripe_warn_complex_cmp (void)
+{
+  warning_with_id ("Octave:matlab-incompatible",
+                   "potential Matlab compatibility problem: comparing complex numbers");
+}
