@@ -1,13 +1,14 @@
 /*
 
-Copyright (C) 1996, 1997 John W. Eaton
+Copyright (C) 1996-2011 John W. Eaton
+Copyright (C) 2009-2010 VZLU Prague
 
 This file is part of Octave.
 
 Octave is free software; you can redistribute it and/or modify it
 under the terms of the GNU General Public License as published by the
-Free Software Foundation; either version 2, or (at your option) any
-later version.
+Free Software Foundation; either version 3 of the License, or (at your
+option) any later version.
 
 Octave is distributed in the hope that it will be useful, but WITHOUT
 ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
@@ -15,9 +16,8 @@ FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 for more details.
 
 You should have received a copy of the GNU General Public License
-along with Octave; see the file COPYING.  If not, write to the Free
-Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-02110-1301, USA.
+along with Octave; see the file COPYING.  If not, see
+<http://www.gnu.org/licenses/>.
 
 */
 
@@ -26,7 +26,7 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 
 #include <cstdlib>
 
-#include <iostream>
+#include <iosfwd>
 #include <string>
 
 #include "mx-base.h"
@@ -39,7 +39,8 @@ Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 #include "ov-base-mat.h"
 #include "ov-typeinfo.h"
 
-class Octave_map;
+#include "MatrixType.h"
+
 class octave_value_list;
 
 class tree_walker;
@@ -47,6 +48,7 @@ class tree_walker;
 // Complex matrix values.
 
 class
+OCTINTERP_API
 octave_complex_matrix : public octave_base_matrix<ComplexNDArray>
 {
 public:
@@ -60,7 +62,10 @@ public:
   octave_complex_matrix (const ComplexMatrix& m)
     : octave_base_matrix<ComplexNDArray> (m) { }
 
-  octave_complex_matrix (const ArrayN<Complex>& m)
+  octave_complex_matrix (const ComplexMatrix& m, const MatrixType& t)
+    : octave_base_matrix<ComplexNDArray> (m, t) { }
+
+  octave_complex_matrix (const Array<Complex>& m)
     : octave_base_matrix<ComplexNDArray> (ComplexNDArray (m)) { }
 
   octave_complex_matrix (const ComplexDiagMatrix& d)
@@ -77,69 +82,95 @@ public:
 
   ~octave_complex_matrix (void) { }
 
-  octave_value *clone (void) const { return new octave_complex_matrix (*this); }
-  octave_value *empty_clone (void) const { return new octave_complex_matrix (); }
+  octave_base_value *clone (void) const { return new octave_complex_matrix (*this); }
+  octave_base_value *empty_clone (void) const { return new octave_complex_matrix (); }
 
-  octave_value *try_narrowing_conversion (void);
+  type_conv_info numeric_demotion_function (void) const;
 
-  void assign (const octave_value_list& idx, const ComplexNDArray& rhs);
+  octave_base_value *try_narrowing_conversion (void);
 
-  void assign (const octave_value_list& idx, const NDArray& rhs);
+  builtin_type_t builtin_type (void) const { return btyp_complex; }
 
   bool is_complex_matrix (void) const { return true; }
 
   bool is_complex_type (void) const { return true; }
 
-  bool valid_as_scalar_index (void) const;
+  bool is_double_type (void) const { return true; }
+
+  bool is_float_type (void) const { return true; }
 
   double double_value (bool = false) const;
 
+  float float_value (bool = false) const;
+
   double scalar_value (bool frc_str_conv = false) const
     { return double_value (frc_str_conv); }
 
+  float float_scalar_value (bool frc_str_conv = false) const
+    { return float_value (frc_str_conv); }
+
   Matrix matrix_value (bool = false) const;
 
+  FloatMatrix float_matrix_value (bool = false) const;
+
   Complex complex_value (bool = false) const;
 
+  FloatComplex float_complex_value (bool = false) const;
+
   ComplexMatrix complex_matrix_value (bool = false) const;
 
+  FloatComplexMatrix float_complex_matrix_value (bool = false) const;
+
   ComplexNDArray complex_array_value (bool = false) const { return matrix; }
 
+  FloatComplexNDArray float_complex_array_value (bool = false) const;
+
+  boolNDArray bool_array_value (bool warn = false) const;
+
+  charNDArray char_array_value (bool frc_str_conv = false) const;
+
   SparseMatrix sparse_matrix_value (bool = false) const;
 
   SparseComplexMatrix sparse_complex_matrix_value (bool = false) const;
 
+  octave_value diag (octave_idx_type k = 0) const;
+
   void increment (void) { matrix += Complex (1.0); }
 
   void decrement (void) { matrix -= Complex (1.0); }
 
-  bool save_ascii (std::ostream& os, bool& infnan_warned,
-		 bool strip_nan_and_inf);
+  void changesign (void) { matrix.changesign (); }
+
+  bool save_ascii (std::ostream& os);
 
   bool load_ascii (std::istream& is);
 
   bool save_binary (std::ostream& os, bool& save_as_floats);
 
-  bool load_binary (std::istream& is, bool swap, 
-		    oct_mach_info::float_format fmt);
+  bool load_binary (std::istream& is, bool swap,
+                    oct_mach_info::float_format fmt);
 
 #if defined (HAVE_HDF5)
   bool save_hdf5 (hid_t loc_id, const char *name, bool save_as_floats);
 
-  bool load_hdf5 (hid_t loc_id, const char *name, bool have_h5giterate_bug);
+  bool load_hdf5 (hid_t loc_id, const char *name);
 #endif
 
   int write (octave_stream& os, int block_size,
-	     oct_data_conv::data_type output_type, int skip,
-	     oct_mach_info::float_format flt_fmt) const
+             oct_data_conv::data_type output_type, int skip,
+             oct_mach_info::float_format flt_fmt) const
     {
       // Yes, for compatibility, we drop the imaginary part here.
       return os.write (matrix_value (true), block_size, output_type,
-		       skip, flt_fmt);
+                       skip, flt_fmt);
     }
 
   void print_raw (std::ostream& os, bool pr_as_read_syntax = false) const;
 
+  mxArray *as_mxArray (void) const;
+
+  octave_value map (unary_mapper_t umap) const;
+
 private:
 
   DECLARE_OCTAVE_ALLOCATOR
@@ -148,9 +179,3 @@ private:
 };
 
 #endif
-
-/*
-;;; Local Variables: ***
-;;; mode: C++ ***
-;;; End: ***
-*/
