@@ -591,7 +591,8 @@ octave_value_typeinfo::do_installed_type_names (void)
 
 DEFUN (typeinfo, args, ,
   "-*- texinfo -*-\n\
-@deftypefn {Built-in Function} {} typeinfo (@var{expr})\n\
+@deftypefn  {Built-in Function} {} typeinfo ()\n\
+@deftypefnx {Built-in Function} {} typeinfo (@var{expr})\n\
 \n\
 Return the type of the expression @var{expr}, as a string.  If\n\
 @var{expr} is omitted, return an array of strings containing all the\n\
