@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# Copyright (C) 2006, 2007 David Bateman
+# Copyright (C) 2006-2011 David Bateman
 #
 # This file is part of Octave.
 # 
@@ -21,17 +21,18 @@
 # Some tests are commented out because they are known to be broken!
 # Search for "# fails"   
 
-# ./buildtest.sh preset
+# ./build_sparse_tests.sh preset
 #    creates test_sparse.m with preset tests.
 #    Use "test test_sparse" from octave to run the tests.
 #
-# ./buildtest.sh random
+# ./build_sparse_tests.sh random
 #    Creates test_sprandom.m with randomly generated matrices.
+#    Use "test test_sprandom" from octave to run the tests.
 
-# buildtest.sh generates tests for real and complex sparse matrices.
+# build_sparse_tests.sh generates tests for real and complex sparse matrices.
 # Also, we want to run both fixed tests with known outputs (quick tests)
 # and longer tests with unknown outputs (thorough tests).  This requires
-# two sets of tests --- one which uses preset matrices and another which
+# two sets of tests -- one which uses preset matrices and another which
 # uses randomly generated matrices.
 #
 # The tests are mostly identical for each case but the code is different,
@@ -109,7 +110,7 @@ case $1 in
     random) preset=false ;;
     preset) preset=true ;;
     '') preset=true ;;
-    *) echo "buildtest.sh random|preset" && exit 1 ;;
+    *) echo "build_sparse_tests.sh random|preset" && exit 1 ;;
 esac
 
 if $preset; then
@@ -179,11 +180,12 @@ cat >>$TESTS <<EOF
 %% Note that the last four do not fail, but rather give a warning
 %% of a singular matrix, which is consistent with the full matrix
 %% behaviour. They are therefore disabled.. 
-%!assert(spinv(sparse([1,1;1,1+i])),sparse([1-1i,1i;1i,-1i]),10*eps);
-% !error spinv( sparse( [1,1;1,1]   ) );
-% !error spinv( sparse( [0,0;0,1]   ) );
-% !error spinv( sparse( [0,0;0,1+i] ) );
-% !error spinv( sparse( [0,0;0,0]   ) );
+%!testif HAVE_UMFPACK
+%! assert(inv(sparse([1,1;1,1+i])),sparse([1-1i,1i;1i,-1i]),10*eps);
+% !error inv( sparse( [1,1;1,1]   ) );
+% !error inv( sparse( [0,0;0,1]   ) );
+% !error inv( sparse( [0,0;0,1+i] ) );
+% !error inv( sparse( [0,0;0,0]   ) );
 
 %% error handling in constructor
 %!error sparse(1,[2,3],[1,2,3]);
@@ -215,7 +217,7 @@ gen_specific_tests() {
 %!test
 %! wdbz = warning ("query", "Octave:divide-by-zero");
 %! warning ("off", "Octave:divide-by-zero");
-%! assert(sparse(eye(3))/0,sparse(eye(3)/0,1));
+%! assert(full(sparse(eye(3))/0),full(eye(3)/0));
 %! warning (wdbz.state, "Octave:divide-by-zero");
 
 EOF
@@ -251,7 +253,7 @@ EOF
 ##  end
 ##  The test log is appended to sprandomtest.log
 function [passes,total] = test_sprandom
-  warning("untested --- fix the source in buildtests.sh");
+  warning("untested --- fix the source in build_sparse_tests.sh");
   disp("appending test output to sprandomtest.log");
   fid = fopen("sprandomtest.log","at");
   test("test_sprandom","normal",fid);
@@ -272,27 +274,27 @@ EOF
 gen_ordering_tests() {
     cat >>$TESTS <<EOF
 %% real values can be ordered (uses as,af)
-%!assert(as<=bf,sparse(af<=bf,true))
-%!assert(bf<=as,sparse(bf<=af,true))
+%!assert(as<=bf,sparse(af<=bf))
+%!assert(bf<=as,sparse(bf<=af))
 
-%!assert(as>=bf,sparse(af>=bf,true))
-%!assert(bf>=as,sparse(bf>=af,true))
+%!assert(as>=bf,sparse(af>=bf))
+%!assert(bf>=as,sparse(bf>=af))
 
-%!assert(as<bf,sparse(af<bf,true))
-%!assert(bf<as,sparse(bf<af,true))
+%!assert(as<bf,sparse(af<bf))
+%!assert(bf<as,sparse(bf<af))
 
-%!assert(as>bf,sparse(af>bf,true))
-%!assert(bf>as,sparse(bf>af,true))
+%!assert(as>bf,sparse(af>bf))
+%!assert(bf>as,sparse(bf>af))
 
 EOF
 }
 
 gen_sparsesparse_ordering_tests() {
     cat >>$TESTS <<EOF
-%!assert(as<=bs,sparse(af<=bf,true))
-%!assert(as>=bs,sparse(af>=bf,true))
-%!assert(as<bs,sparse(af<bf,true))
-%!assert(as>bs,sparse(af>bf,true))
+%!assert(as<=bs,sparse(af<=bf))
+%!assert(as>=bs,sparse(af>=bf))
+%!assert(as<bs,sparse(af<bf))
+%!assert(as>bs,sparse(af>bf))
 EOF
 }
 
@@ -300,11 +302,11 @@ EOF
 gen_elementop_tests() {
     cat >>$TESTS <<EOF
 %% Elementwise binary tests (uses as,af,bs,bf,scalar)
-%!assert(as==bs,sparse(af==bf,true))
-%!assert(bf==as,sparse(bf==af,true))
+%!assert(as==bs,sparse(af==bf))
+%!assert(bf==as,sparse(bf==af))
 
-%!assert(as!=bf,sparse(af!=bf,true))
-%!assert(bf!=as,sparse(bf!=af,true))
+%!assert(as!=bf,sparse(af!=bf))
+%!assert(bf!=as,sparse(bf!=af))
 
 %!assert(as+bf,af+bf)
 %!assert(bf+as,bf+af)
@@ -312,34 +314,34 @@ gen_elementop_tests() {
 %!assert(as-bf,af-bf)
 %!assert(bf-as,bf-af)
 
-%!assert(as.*bf,sparse(af.*bf,true))
-%!assert(bf.*as,sparse(bf.*af,true))
+%!assert(as.*bf,sparse(af.*bf))
+%!assert(bf.*as,sparse(bf.*af))
 
-%!assert(as./bf,sparse(af./bf,true),100*eps)
-%!assert(bf.\as,sparse(bf.\af,true),100*eps)
+%!assert(as./bf,sparse(af./bf),100*eps)
+%!assert(bf.\as,sparse(bf.\af),100*eps)
 
 %!test
 %! sv = as.^bf;
 %! fv = af.^bf;
 %! idx = find(af~=0);
-%! assert(sv(:)(idx),sparse(fv(:)(idx),true),100*eps)
+%! assert(sv(:)(idx),sparse(fv(:)(idx)),100*eps)
 
 EOF
 }
 
 gen_sparsesparse_elementop_tests() {
     cat >>$TESTS <<EOF
-%!assert(as==bs,sparse(af==bf,true))
-%!assert(as!=bs,sparse(af!=bf,true))
-%!assert(as+bs,sparse(af+bf,true))
-%!assert(as-bs,sparse(af-bf,true))
-%!assert(as.*bs,sparse(af.*bf,true))
-%!assert(as./bs,sparse(af./bf,true),100*eps);
+%!assert(as==bs,sparse(af==bf))
+%!assert(as!=bs,sparse(af!=bf))
+%!assert(as+bs,sparse(af+bf))
+%!assert(as-bs,sparse(af-bf))
+%!assert(as.*bs,sparse(af.*bf))
+%!xtest assert(as./bs,sparse(af./bf),100*eps);
 %!test
 %! sv = as.^bs;
 %! fv = af.^bf;
 %! idx = find(af~=0);
-%! assert(sv(:)(idx),sparse(fv(:)(idx),true),100*eps)
+%! assert(sv(:)(idx),sparse(fv(:)(idx)),100*eps)
 
 EOF
 }
@@ -350,10 +352,10 @@ gen_divop_tests() {
 %% Matrix-matrix operators (uses af,as,bs,bf)
 %!assert(as/bf,af/bf,100*eps)
 %!assert(af/bs,af/bf,100*eps)
-%!assert(as/bs,sparse(af/bf,true),100*eps)
+%!assert(as/bs,sparse(af/bf),100*eps)
 %!assert(bs\af',bf\af',100*eps)
 %!assert(bf\as',bf\af',100*eps)
-%!assert(bs\as',sparse(bf\af',true),100*eps)
+%!assert(bs\as',sparse(bf\af'),100*eps)
 
 EOF
 }
@@ -364,10 +366,10 @@ gen_square_divop_tests() {
 %% Matrix-matrix operators (uses af,as,bs,bf)
 %!assert(as/bf,af/bf,100*eps)
 %!assert(af/bs,af/bf,100*eps)
-%!assert(as/bs,sparse(af/bf,true),100*eps)
+%!assert(as/bs,sparse(af/bf),100*eps)
 %!assert(bs\af',bf\af',100*eps)
 %!assert(bf\as',bf\af',100*eps)
-%!assert(bs\as',sparse(bf\af',true),100*eps)
+%!assert(bs\as',sparse(bf\af'),100*eps)
 
 EOF
 }
@@ -378,7 +380,7 @@ gen_matrixop_tests() {
 %% Matrix-matrix operators (uses af,as,bs,bf)
 %!assert(as*bf',af*bf')
 %!assert(af*bs',af*bf')
-%!assert(as*bs',sparse(af*bf',true))
+%!assert(as*bs',sparse(af*bf'))
 
 EOF
 }
@@ -387,18 +389,18 @@ EOF
 gen_matrixdiag_tests() {
     cat >>$TESTS <<EOF
 %% Matrix diagonal tests (uses af,as,bf,bs)
-%!assert(spdiag(as),sparse(diag(af),true))
-%!assert(spdiag(bs),sparse(diag(bf),true))
-%!assert(spdiag(as,1),sparse(diag(af,1),true))
-%!assert(spdiag(bs,1),sparse(diag(bf,1),true))
-%!assert(spdiag(as,-1),sparse(diag(af,-1),true))
-%!assert(spdiag(bs,-1),sparse(diag(bf,-1),true))
-%!assert(spdiag(as(:)),sparse(diag(af(:)),true))
-%!assert(spdiag(as(:),1),sparse(diag(af(:),1),true))
-%!assert(spdiag(as(:),-1),sparse(diag(af(:),-1),true))
-%!assert(spdiag(as(:)'),sparse(diag(af(:)'),true))
-%!assert(spdiag(as(:)',1),sparse(diag(af(:)',1),true))
-%!assert(spdiag(as(:)',-1),sparse(diag(af(:)',-1),true))
+%!assert(diag(as),sparse(diag(af)))
+%!assert(diag(bs),sparse(diag(bf)))
+%!assert(diag(as,1),sparse(diag(af,1)))
+%!assert(diag(bs,1),sparse(diag(bf,1)))
+%!assert(diag(as,-1),sparse(diag(af,-1)))
+%!assert(diag(bs,-1),sparse(diag(bf,-1)))
+%!assert(diag(as(:)),sparse(diag(af(:))))
+%!assert(diag(as(:),1),sparse(diag(af(:),1)))
+%!assert(diag(as(:),-1),sparse(diag(af(:),-1)))
+%!assert(diag(as(:)'),sparse(diag(af(:)')))
+%!assert(diag(as(:)',1),sparse(diag(af(:)',1)))
+%!assert(diag(as(:)',-1),sparse(diag(af(:)',-1)))
 %!assert(spdiags(as,[0,1]),[diag(af,0),diag(af,1)])
 %!test [tb,tc]=spdiags(as); 
 %! assert(spdiags(tb,tc,sparse(zeros(size(as)))),as)
@@ -411,19 +413,19 @@ EOF
 gen_matrixreshape_tests() {
     cat >>$TESTS <<EOF
 %% Matrix diagonal tests (uses af,as,bf,bs)
-%!assert(reshape(as,1,prod(size(as))),sparse(reshape(af,1,prod(size(af))),true))
-%!assert(reshape(as,prod(size(as)),1),sparse(reshape(af,prod(size(af)),1),true))
-%!assert(reshape(as,fliplr(size(as))),sparse(reshape(af,fliplr(size(af))),true))
-%!assert(reshape(bs,1,prod(size(as))),sparse(reshape(bf,1,prod(size(af))),true))
-%!assert(reshape(bs,prod(size(as)),1),sparse(reshape(bf,prod(size(af)),1),true))
-%!assert(reshape(bs,fliplr(size(as))),sparse(reshape(bf,fliplr(size(af))),true))
+%!assert(reshape(as,1,prod(size(as))),sparse(reshape(af,1,prod(size(af)))))
+%!assert(reshape(as,prod(size(as)),1),sparse(reshape(af,prod(size(af)),1)))
+%!assert(reshape(as,fliplr(size(as))),sparse(reshape(af,fliplr(size(af)))))
+%!assert(reshape(bs,1,prod(size(as))),sparse(reshape(bf,1,prod(size(af)))))
+%!assert(reshape(bs,prod(size(as)),1),sparse(reshape(bf,prod(size(af)),1)))
+%!assert(reshape(bs,fliplr(size(as))),sparse(reshape(bf,fliplr(size(af)))))
 
 EOF
 }
 
 # test mapper matrix operations: uses as,af
 print_mapper_test() {
-echo "%!assert($1(as),sparse($1(af),1))" >>$TESTS
+echo "%!assert($1(as),sparse($1(af)))" >>$TESTS
 }
 
 print_real_mapper_test() {
@@ -433,7 +435,7 @@ print_real_mapper_test() {
 %! warning ("off", "Octave:num-to-str");
 %! if isreal(af)
 %!   if ($2)
-%!     assert($1(as),sparse($1(af),1))
+%!     assert($1(as),sparse($1(af)))
 %!   else
 %!     assert($1(as),$1(af))
 %!   endif
@@ -530,71 +532,71 @@ gen_unaryop_tests() {
 %!assert(!issparse(af))
 %!assert(!(issparse(af)&&iscomplex(af)))
 %!assert(!(issparse(af)&&isreal(af)))
-%!assert(spsum(as),sparse(sum(af),true))
-%!assert(spsum(as,1),sparse(sum(af,1),true))
-%!assert(spsum(as,2),sparse(sum(af,2),true))
-%!assert(spcumsum(as),sparse(cumsum(af),true))
-%!assert(spcumsum(as,1),sparse(cumsum(af,1),true))
-%!assert(spcumsum(as,2),sparse(cumsum(af,2),true))
-%!assert(spsumsq(as),sparse(sumsq(af),true))
-%!assert(spsumsq(as,1),sparse(sumsq(af,1),true))
-%!assert(spsumsq(as,2),sparse(sumsq(af,2),true))
-%!assert(spprod(as),sparse(prod(af),true))
-%!assert(spprod(as,1),sparse(prod(af,1),true))
-%!assert(spprod(as,2),sparse(prod(af,2),true))
-%!assert(spcumprod(as),sparse(cumprod(af),true))
-%!assert(spcumprod(as,1),sparse(cumprod(af,1),true))
-%!assert(spcumprod(as,2),sparse(cumprod(af,2),true))
+%!assert(sum(as),sparse(sum(af)))
+%!assert(sum(as,1),sparse(sum(af,1)))
+%!assert(sum(as,2),sparse(sum(af,2)))
+%!assert(cumsum(as),sparse(cumsum(af)))
+%!assert(cumsum(as,1),sparse(cumsum(af,1)))
+%!assert(cumsum(as,2),sparse(cumsum(af,2)))
+%!assert(sumsq(as),sparse(sumsq(af)))
+%!assert(sumsq(as,1),sparse(sumsq(af,1)))
+%!assert(sumsq(as,2),sparse(sumsq(af,2)))
+%!assert(prod(as),sparse(prod(af)))
+%!assert(prod(as,1),sparse(prod(af,1)))
+%!assert(prod(as,2),sparse(prod(af,2)))
+%!assert(cumprod(as),sparse(cumprod(af)))
+%!assert(cumprod(as,1),sparse(cumprod(af,1)))
+%!assert(cumprod(as,2),sparse(cumprod(af,2)))
 
-%!assert(spmin(as),sparse(min(af),true))
-%!assert(spmin(as(:)),min(af(:)))
-%!assert(spmin(as,[],1),sparse(min(af,[],1),true))
-%!assert(spmin(as,[],2),sparse(min(af,[],2),true))
-%!assert(spmin(as,[],1),sparse(min(af,[],1),true))
-%!assert(spmin(as,0),sparse(min(af,0),true))
-%!assert(spmin(as,bs),sparse(min(af,bf),true))
-%!assert(spmax(as),sparse(max(af),true))
-%!assert(spmax(as(:)),max(af(:)))
-%!assert(spmax(as,[],1),sparse(max(af,[],1),true))
-%!assert(spmax(as,[],2),sparse(max(af,[],2),true))
-%!assert(spmax(as,[],1),sparse(max(af,[],1),true))
-%!assert(spmax(as,0),sparse(max(af,0),true))
-%!assert(spmax(as,bs),sparse(max(af,bf),true))
+%!assert(min(as),sparse(min(af)))
+%!assert(full(min(as(:))),min(af(:)))
+%!assert(min(as,[],1),sparse(min(af,[],1)))
+%!assert(min(as,[],2),sparse(min(af,[],2)))
+%!assert(min(as,[],1),sparse(min(af,[],1)))
+%!assert(min(as,0),sparse(min(af,0)))
+%!assert(min(as,bs),sparse(min(af,bf)))
+%!assert(max(as),sparse(max(af)))
+%!assert(full(max(as(:))),max(af(:)))
+%!assert(max(as,[],1),sparse(max(af,[],1)))
+%!assert(max(as,[],2),sparse(max(af,[],2)))
+%!assert(max(as,[],1),sparse(max(af,[],1)))
+%!assert(max(as,0),sparse(max(af,0)))
+%!assert(max(as,bs),sparse(max(af,bf)))
 
 %!assert(as==as)
 %!assert(as==af)
 %!assert(af==as)
 %!test
-%! [ii,jj,vv,nr,nc] = spfind(as);
+%! [ii,jj,vv,nr,nc] = find(as);
 %! assert(af,full(sparse(ii,jj,vv,nr,nc)));
 %!assert(nnz(as),sum(af(:)!=0))
 %!assert(nnz(as),nnz(af))
 %!assert(issparse(as.'))
 %!assert(issparse(as'))
 %!assert(issparse(-as))
-%!assert(~as,sparse(~af,true))
-%!assert(as.', sparse(af.',true));
-%!assert(as',  sparse(af',true));
-%!assert(-as, sparse(-af,true));
-%!assert(~as, sparse(~af,true));
+%!assert(~as,sparse(~af))
+%!assert(as.', sparse(af.'));
+%!assert(as',  sparse(af'));
+%!assert(-as, sparse(-af));
+%!assert(~as, sparse(~af));
 %!error [i,j]=size(af);as(i-1,j+1);
 %!error [i,j]=size(af);as(i+1,j-1);
 %!test
-%! [Is,Js,Vs] = spfind(as);
+%! [Is,Js,Vs] = find(as);
 %! [If,Jf,Vf] = find(af);
 %! assert(Is,If);
 %! assert(Js,Jf);
 %! assert(Vs,Vf);
 %!error as(0,1);
 %!error as(1,0);
-%!assert(spfind(as),find(af))
+%!assert(find(as),find(af))
 %!test
-%! [i,j,v] = spfind(as);
+%! [i,j,v] = find(as);
 %! [m,n] = size(as);
 %! x = sparse(i,j,v,m,n);
 %! assert(x,as);
 %!test
-%! [i,j,v,m,n] = spfind(as);
+%! [i,j,v,m,n] = find(as);
 %! x = sparse(i,j,v,m,n);
 %! assert(x,as);
 %!assert(issparse(horzcat(as,as)));
@@ -629,59 +631,60 @@ gen_square_tests() {
     gen_square_divop_tests
 
     cat >>$TESTS <<EOF
-%!assert(spdet(bs+speye(size(bs))),det(bf+eye(size(bf))),100*eps*abs(det(bf+eye(size(bf)))))
+%!testif HAVE_UMFPACK
+%! assert(det(bs+speye(size(bs))),det(bf+eye(size(bf))),100*eps*abs(det(bf+eye(size(bf)))))
 
-%!test 
-%! [l,u]=splu(sparse([1,1;1,1]));
+%!testif HAVE_UMFPACK 
+%! [l,u]=lu(sparse([1,1;1,1]));
 %! assert(l*u,[1,1;1,1],10*eps);
 
-%!test
-%! [l,u]=splu(sparse([1,1;1,1+i]));
+%!testif HAVE_UMFPACK
+%! [l,u]=lu(sparse([1,1;1,1+i]));
 %! assert(l,sparse([1,2,2],[1,1,2],1),10*eps);
 %! assert(u,sparse([1,1,2],[1,2,2],[1,1,1i]),10*eps);
 
-%!test ;# permuted LU
-%! [L,U] = splu(bs);
+%!testif HAVE_UMFPACK ;# permuted LU
+%! [L,U] = lu(bs);
 %! assert(L*U,bs,1e-10);
 
-%!test ;# simple LU + row permutations
-%! [L,U,P] = splu(bs);
+%!testif HAVE_UMFPACK ;# simple LU + row permutations
+%! [L,U,P] = lu(bs);
 %! assert(P'*L*U,bs,1e-10);
 %! # triangularity
-%! [i,j,v]=spfind(L);
+%! [i,j,v]=find(L);
 %! assert(i-j>=0);
-%! [i,j,v]=spfind(U);
+%! [i,j,v]=find(U);
 %! assert(j-i>=0);
 
-%!test ;# simple LU + row/col permutations
-%! [L,U,P,Q] = splu(bs);
+%!testif HAVE_UMFPACK ;# simple LU + row/col permutations
+%! [L,U,P,Q] = lu(bs);
 %! assert(P'*L*U*Q',bs,1e-10);
 %! # triangularity
-%! [i,j,v]=spfind(L);
+%! [i,j,v]=find(L);
 %! assert(i-j>=0);
-%! [i,j,v]=spfind(U);
+%! [i,j,v]=find(U);
 %! assert(j-i>=0);
 
-%!test ;# LU with fixed column permutation
-%! [L,U,P] = splu(bs,colamd(bs));
-%! assert(P'*L*U,bs,1e-10);
+%!testif HAVE_UMFPACK ;# LU with vector permutations
+%! [L,U,P,Q] = lu(bs,'vector');
+%! assert(L(P,:)*U(:,Q),bs,1e-10);
 %! # triangularity
-%! [i,j,v]=spfind(L);
+%! [i,j,v]=find(L);
 %! assert(i-j>=0);
-%! [i,j,v]=spfind(U(:,colamd(bs)));
+%! [i,j,v]=find(U);
 %! assert(j-i>=0);
 
-%!test ;# LU with initial column permutation
-%! [L,U,P,Q] = splu(bs,colamd(bs));
-%! assert(P'*L*U*Q',bs,1e-10);
+%!testif HAVE_UMFPACK ;# LU with scaling
+%! [L,U,P,Q,R] = lu(bs);
+%! assert(R*P'*L*U*Q',bs,1e-10);
 %! # triangularity
-%! [i,j,v]=spfind(L);
+%! [i,j,v]=find(L);
 %! assert(i-j>=0);
-%! [i,j,v]=spfind(U);
+%! [i,j,v]=find(U);
 %! assert(j-i>=0);
 
-%!test ;# inverse
-%! assert(spinv(bs)*bs,sparse(eye(rows(bs))),1e-10);
+%!testif HAVE_UMFPACK ;# inverse
+%! assert(inv(bs)*bs,sparse(eye(rows(bs))),1e-10);
 
 %!assert(bf\as',bf\af',100*eps);
 %!assert(bs\af',bf\af',100*eps);
@@ -693,23 +696,26 @@ EOF
 # Cholesky tests
 gen_cholesky_tests() {
     cat >>$TESTS <<EOF
-%!assert(spchol(bs)'*spchol(bs),bs,1e-10);
-%!assert(splchol(bs)*splchol(bs)',bs,1e-10);
-%!assert(splchol(bs),spchol(bs)',1e-10);
+%!testif HAVE_CHOLMOD
+%! assert(chol(bs)'*chol(bs),bs,1e-10);
+%!testif HAVE_CHOLMOD 
+%! assert(chol(bs,'lower')*chol(bs,'lower')',bs,1e-10);
+%!testif HAVE_CHOLMOD
+%! assert(chol(bs,'lower'),chol(bs)',1e-10);
 
-%!test ;# Return Partial Cholesky factorization
-%! [RS,PS] = spchol(bs);
+%!testif HAVE_CHOLMOD ;# Return Partial Cholesky factorization
+%! [RS,PS] = chol(bs);
 %! assert(RS'*RS,bs,1e-10);
 %! assert(PS,0);
-%! [LS,PS] = splchol(bs);
+%! [LS,PS] = chol(bs,'lower');
 %! assert(LS*LS',bs,1e-10);
 %! assert(PS,0);
 
-%!test ;# Permuted Cholesky factorization
-%! [RS,PS,QS] = spchol(bs);
+%!testif HAVE_CHOLMOD ;# Permuted Cholesky factorization
+%! [RS,PS,QS] = chol(bs);
 %! assert(RS'*RS,QS*bs*QS',1e-10);
 %! assert(PS,0);
-%! [LS,PS,QS] = splchol(bs);
+%! [LS,PS,QS] = chol(bs,'lower');
 %! assert(LS*LS',QS*bs*QS',1e-10);
 %! assert(PS,0);
 
@@ -740,6 +746,48 @@ gen_rectangular_tests() {
     # gen_divop_tests # Disable rectangular \ and / for now
     gen_matrixdiag_tests
     gen_matrixreshape_tests
+    cat >>$TESTS <<EOF
+%!testif HAVE_UMFPACK ;# permuted LU
+%! [L,U] = lu(bs);
+%! assert(L*U,bs,1e-10);
+
+%!testif HAVE_UMFPACK ;# simple LU + row permutations
+%! [L,U,P] = lu(bs);
+%! assert(P'*L*U,bs,1e-10);
+%! # triangularity
+%! [i,j,v]=find(L);
+%! assert(i-j>=0);
+%! [i,j,v]=find(U);
+%! assert(j-i>=0);
+
+%!testif HAVE_UMFPACK ;# simple LU + row/col permutations
+%! [L,U,P,Q] = lu(bs);
+%! assert(P'*L*U*Q',bs,1e-10);
+%! # triangularity
+%! [i,j,v]=find(L);
+%! assert(i-j>=0);
+%! [i,j,v]=find(U);
+%! assert(j-i>=0);
+
+%!testif HAVE_UMFPACK ;# LU with vector permutations
+%! [L,U,P,Q] = lu(bs,'vector');
+%! assert(L(P,:)*U(:,Q),bs,1e-10);
+%! # triangularity
+%! [i,j,v]=find(L);
+%! assert(i-j>=0);
+%! [i,j,v]=find(U);
+%! assert(j-i>=0);
+
+%!testif HAVE_UMFPACK ;# LU with scaling
+%! [L,U,P,Q,R] = lu(bs);
+%! assert(R*P'*L*U*Q',bs,1e-10);
+%! # triangularity
+%! [i,j,v]=find(L);
+%! assert(i-j>=0);
+%! [i,j,v]=find(U);
+%! assert(j-i>=0);
+
+EOF
 }
 
 
@@ -785,59 +833,73 @@ EOF
 # =======================================================
 # sparse selection tests
 
+gen_scalar_select_tests () {
+    cat >>$TESTS <<EOF
+%!assert (sparse(42)([1,1]),sparse([42,42]))
+%!assert (sparse(42*1i)([1,1]),sparse([42,42].*1i))
+EOF
+}
+
 gen_select_tests() {
     cat >>$TESTS <<EOF
 %!test as=sparse(af);
 
 %% Point tests
 %!test idx=ridx(:)+rows(as)*(cidx(:)-1);
-%!assert(sparse(as(idx),true),sparse(af(idx),true));
-%!assert(as(idx),sparse(af(idx),true));
-%!assert(as(idx'),sparse(af(idx'),true));
-%!assert(as(flipud(idx(:))),sparse(af(flipud(idx(:))),true))
-%!assert(as([idx,idx]),sparse(af([idx,idx]),true));
+%!assert(sparse(as(idx)),sparse(af(idx)));
+%!assert(as(idx),sparse(af(idx)));
+%!assert(as(idx'),sparse(af(idx')));
+%!assert(as(flipud(idx(:))),sparse(af(flipud(idx(:)))))
+%!assert(as([idx,idx]),sparse(af([idx,idx])));
 %!error(as(reshape([idx;idx],[1,length(idx),2])));
 
 %% Slice tests
-%!assert(as(ridx,cidx), sparse(af(ridx,cidx),true))
-%!assert(as(ridx,:), sparse(af(ridx,:),true))
-%!assert(as(:,cidx), sparse(af(:,cidx),true))
-%!assert(as(:,:), sparse(af(:,:),true))
-%!assert(as((size(as,1):-1:1),:),sparse(af((size(af,1):-1:1),:),true))
-%!assert(as(:,(size(as,2):-1:1)),sparse(af(:,(size(af,2):-1:1)),true))
+%!assert(as(ridx,cidx), sparse(af(ridx,cidx)))
+%!assert(as(ridx,:), sparse(af(ridx,:)))
+%!assert(as(:,cidx), sparse(af(:,cidx)))
+%!assert(as(:,:), sparse(af(:,:)))
+%!assert(as((size(as,1):-1:1),:),sparse(af((size(af,1):-1:1),:)))
+%!assert(as(:,(size(as,2):-1:1)),sparse(af(:,(size(af,2):-1:1))))
+
+%% Indexing tests
+%!assert(full(as([1,1],:)), af([1,1],:))
+%!assert(full(as(:,[1,1])), af(:,[1,1]))
+%!test
+%! [i,j,v] = find (as);
+%! assert (as(i(1),j(1))([1,1]), sparse([v(1),v(1)]))
 
 %% Assignment test
 %!test
 %! ts=as;ts(:,:)=ts(fliplr(1:size(as,1)),:);
 %! tf=af;tf(:,:)=tf(fliplr(1:size(af,1)),:);
-%! assert(ts,sparse(tf,true));
+%! assert(ts,sparse(tf));
 %!test
 %! ts=as;ts(fliplr(1:size(as,1)),:)=ts;
 %! tf=af;tf(fliplr(1:size(af,1)),:)=tf;
-%! assert(ts,sparse(tf,true));
+%! assert(ts,sparse(tf));
 %!test
 %! ts=as;ts(:,fliplr(1:size(as,2)))=ts;
 %! tf=af;tf(:,fliplr(1:size(af,2)))=tf;
-%! assert(ts,sparse(tf,true));
+%! assert(ts,sparse(tf));
 %!test
 %! ts(fliplr(1:size(as,1)))=as(:,1);tf(fliplr(1:size(af,1)))=af(:,1);
-%! assert(ts,sparse(tf,true));
+%! assert(ts,sparse(tf));
 
 %% Deletion tests
 %!test
 %! ts=as;ts(1,:)=[];tf=af;tf(1,:)=[];
-%! assert(ts,sparse(tf,true));
+%! assert(ts,sparse(tf));
 %!test
 %! ts=as;ts(:,1)=[];tf=af;tf(:,1)=[];
-%! assert(ts,sparse(tf,true));
+%! assert(ts,sparse(tf));
 
 %% Test 'end' keyword
-%!assert(as(end),af(end))
-%!assert(as(1,end), af(1,end))
-%!assert(as(end,1), af(end,1))
-%!assert(as(end,end), af(end,end))
-%!assert(as(2:end,2:end), sparse(af(2:end,2:end),true))
-%!assert(as(1:end-1,1:end-1), sparse(af(1:end-1,1:end-1),true))
+%!assert(full(as(end)), af(end))
+%!assert(full(as(1,end)), af(1,end))
+%!assert(full(as(end,1)), af(end,1))
+%!assert(full(as(end,end)), af(end,end))
+%!assert(as(2:end,2:end), sparse(af(2:end,2:end)))
+%!assert(as(1:end-1,1:end-1), sparse(af(1:end-1,1:end-1)))
 EOF
 }
 
@@ -860,13 +922,16 @@ gen_save_tests() {
 %! load(savefile,"as_save");
 %! unlink(savefile);
 %! assert(as_save,sparse(af));
-%!test # save hdf5
+%!testif HAVE_HDF5 # save hdf5
 %! savefile= tmpnam();
 %! as_save=as; save("-hdf5",savefile,"bf","as_save","af");
 %! clear as_save;
 %! load(savefile,"as_save");
 %! unlink(savefile);
 %! assert(as_save,sparse(af));
+## FIXME -- we should skip (or mark as an expected failure) the test for
+## saving sparse matrices to MAT files when using 64-bit indexing since
+## that is not implemented yet.
 %!test # save matlab
 %! savefile= tmpnam();
 %! as_save=as; save("-mat",savefile,"bf","as_save","af");
@@ -891,7 +956,7 @@ if $preset; then
 EOF
 else
   cat >>$TESTS <<EOF
-%! n=floor(lognormal_rnd(8,2)+1)'
+%! n=floor(lognrnd(8,2)+1)'
 %! ls = tril(sprandn(8,8,0.2),-1).*alpha + n*speye(8); lf = full(ls);
 %! us = triu(sprandn(8,8,0.2),1).*alpha + n*speye(8); uf = full(us);
 %! ts = spdiags(randn(8,3),-1:1,8,8).*alpha; tf = full(ts);
@@ -908,24 +973,32 @@ cat >>$TESTS <<EOF
 %! bcf = bf + bf'; bcs = sparse(bcf);
 %! tcf = tf + tf'; tcs = sparse(tcf);
 %! xf = diag(1:n) + fliplr(diag(1:n)).*beta; xs = sparse(xf);
-%!assert(ds\xf,df\xf),1e-10;
-%!assert(ds\xs,sparse(df\xf,1),1e-10);
+%!assert(ds\xf,df\xf,1e-10);
+%!assert(ds\xs,sparse(df\xf),1e-10);
 %!assert(pds\xf,pdf\xf,1e-10);
-%!assert(pds\xs,sparse(pdf\xf,1),1e-10);
+%!assert(pds\xs,sparse(pdf\xf),1e-10);
 %!assert(ls\xf,lf\xf,1e-10);
 %!assert(sparse(ls\xs),sparse(lf\xf),1e-10);
-%!assert(pls\xf,plf\xf,1e-10);
-%!assert(sparse(pls\xs),sparse(plf\xf),1e-10);
+%!testif HAVE_UMFPACK
+%! assert(pls\xf,plf\xf,1e-10);
+%!testif HAVE_UMFPACK
+%! assert(sparse(pls\xs),sparse(plf\xf),1e-10);
 %!assert(us\xf,uf\xf,1e-10);
 %!assert(sparse(us\xs),sparse(uf\xf),1e-10);
-%!assert(pus\xf,puf\xf,1e-10);
-%!assert(sparse(pus\xs),sparse(puf\xf),1e-10);
+%!testif HAVE_UMFPACK
+%! assert(pus\xf,puf\xf,1e-10);
+%!testif HAVE_UMFPACK
+%! assert(sparse(pus\xs),sparse(puf\xf),1e-10);
 %!assert(bs\xf,bf\xf,1e-10);
 %!assert(sparse(bs\xs),sparse(bf\xf),1e-10);
-%!assert(cs\xf,cf\xf,1e-10);
-%!assert(sparse(cs\xs),sparse(cf\xf),1e-10);
-%!assert(bcs\xf,bcf\xf,1e-10);
-%!assert(sparse(bcs\xs),sparse(bcf\xf),1e-10);
+%!testif HAVE_UMFPACK
+%! assert(cs\xf,cf\xf,1e-10);
+%!testif HAVE_UMFPACK
+%! assert(sparse(cs\xs),sparse(cf\xf),1e-10);
+%!testif HAVE_UMFPACK
+%! assert(bcs\xf,bcf\xf,1e-10);
+%!testif HAVE_UMFPACK
+%! assert(sparse(bcs\xs),sparse(bcf\xf),1e-10);
 %!assert(ts\xf,tf\xf,1e-10);
 %!assert(sparse(ts\xs),sparse(tf\xf),1e-10);
 %!assert(tcs\xf,tcf\xf,1e-10);
@@ -945,7 +1018,7 @@ cat >>$TESTS <<EOF
 %! assert (sparse(a * x), b, feps);
 %! b = sprandn(sz(1),sz(2),0.2)+1i*sprandn(sz(1),sz(2),0.2); x = a \b; 
 %! assert (sparse(a * x), b, feps);
-%!test
+%!testif HAVE_UMFPACK
 %! a = alpha*sprandn(10,11,0.2)+speye(10,11); f(a,[10,2],1e-10);
 %! ## Test this by forcing matrix_type, as can't get a certain 
 %! ## result for over-determined systems.
@@ -960,49 +1033,53 @@ cat >>$TESTS <<EOF
 %! xf = beta * ones(10,2);
 %! xs = speye(10,10);
 %!assert(ds\xf,df\xf,100*eps)
-%!assert(ds\xs,sparse(df\xs,true),100*eps)
+%!assert(ds\xs,sparse(df\xs),100*eps)
 %!test
 %! pds = ds([2,1,3:10],:);
 %! pdf = full(pds);
 %!assert(pds\xf,pdf\xf,100*eps)
-%!assert(pds\xs,sparse(pdf\xs,true),100*eps)
+%!assert(pds\xs,sparse(pdf\xs),100*eps)
 %!test
 %! ds = alpha * spdiags([1:11]',0,11,10);
 %! df = full(ds);
 %! xf = beta * ones(11,2);
 %! xs = speye(11,11);
 %!assert(ds\xf,df\xf,100*eps)
-%!assert(ds\xs,sparse(df\xs,true),100*eps)
+%!assert(ds\xs,sparse(df\xs),100*eps)
 %!test
 %! pds = ds([2,1,3:11],:);
 %! pdf = full(pds);
 %!assert(pds\xf,pdf\xf,100*eps)
-%!assert(pds\xs,sparse(pdf\xs,true),100*eps)
+%!assert(pds\xs,sparse(pdf\xs),100*eps)
 %!test
 %! us = alpha*[[speye(10,10);sparse(1,10)],[[1,1];sparse(9,2);[1,1]]];
-%!assert(us*(us\xf),xf,100*eps)
-%!assert(us*(us\xs),xs,100*eps)
+%!testif HAVE_UMFPACK
+%! assert(us*(us\xf),xf,100*eps)
+%!testif HAVE_UMFPACK
+%! assert(us*(us\xs),xs,100*eps)
 %!test
 %! pus = us(:,[2,1,3:12]);
-%!assert(pus*(pus\xf),xf,100*eps)
-%!assert(pus*(pus\xs),xs,100*eps)
+%!testif HAVE_UMFPACK
+%! assert(pus*(pus\xf),xf,100*eps)
+%!testif HAVE_UMFPACK
+%! assert(pus*(pus\xs),xs,100*eps)
 %!test
 %! us = alpha*[speye(11,9),[1;sparse(8,1);1;0]];
-%!test
-%! [c,r] = spqr (us, xf);
+%!testif HAVE_CXSPARSE
+%! [c,r] = qr (us, xf);
 %! assert(us\xf,r\c,100*eps)
-%!test
-%! [c,r] = spqr (us, xs);
+%!testif HAVE_UMFPACK
+%! [c,r] = qr (us, xs);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(us\xs,r\c,100*eps)
 %!test
 %! pus = us(:,[1:8,10,9]);
-%!test
-%! [c,r] = spqr (pus, xf);
+%!testif HAVE_UMFPACK
+%! [c,r] = qr (pus, xf);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(pus\xf,r\c,100*eps)
-%!test
-%! [c,r] = spqr (pus, xs);
+%!testif HAVE_UMFPACK
+%! [c,r] = qr (pus, xs);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(pus\xs,r\c,100*eps)
 %!test
@@ -1019,21 +1096,21 @@ cat >>$TESTS <<EOF
 %! ls = alpha*[speye(10,10),sparse(10,1);[1;1],sparse(2,9),[1;1]];
 %! xf = beta * ones(12,2);
 %! xs = speye(12,12);
-%!test
-%! [c,r] = spqr (ls, xf);
+%!testif HAVE_UMFPACK
+%! [c,r] = qr (ls, xf);
 %! assert(ls\xf,r\c,100*eps)
-%!test
-%! [c,r] = spqr (ls, xs);
+%!testif HAVE_UMFPACK
+%! [c,r] = qr (ls, xs);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(ls\xs,r\c,100*eps)
-%!test
+%!testif HAVE_CXSPARSE
 %! pls = ls(:,[1:8,10,9]);
-%!test
-%! [c,r] = spqr (pls, xf);
+%!testif HAVE_UMFPACK
+%! [c,r] = qr (pls, xf);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(pls\xf,r\c,100*eps)
-%!test
-%! [c,r] = spqr (pls, xs);
+%!testif HAVE_UMFPACK
+%! [c,r] = qr (pls, xs);
 %! r = matrix_type(r,"Singular"); ## Force Matrix Type
 %! assert(pls\xs,r\c,100*eps)
 
@@ -1064,8 +1141,8 @@ else
     cat >>$TESTS <<EOF
 %!test
 %! % generate m,n from 1 to <5000
-%! m=floor(lognormal_rnd(8,2)+1);
-%! n=floor(lognormal_rnd(8,2)+1);
+%! m=floor(lognrnd(8,2)+1);
+%! n=floor(lognrnd(8,2)+1);
 %! as=sprandn(m,n,0.3); af = full(as+1i*sprandn(as));
 %! bf = randn;
 EOF
@@ -1081,8 +1158,8 @@ if $preset; then
 else
     cat >>$TESTS <<EOF
 %!test
-%! m=floor(lognormal_rnd(8,2)+1);
-%! n=floor(lognormal_rnd(8,2)+1);
+%! m=floor(lognrnd(8,2)+1);
+%! n=floor(lognrnd(8,2)+1);
 %! as=sprandn(m,n,0.3); af = full(as+1i*sprandn(as));
 %! bs=sprandn(m,n,0.3); bf = full(bs+1i*sprandn(bs));
 EOF
@@ -1114,8 +1191,8 @@ if $preset; then
 else
     cat >>$TESTS <<EOF
 %!test
-%! m=floor(lognormal_rnd(8,2)+1);
-%! n=floor(lognormal_rnd(8,2)+1);
+%! m=floor(lognrnd(8,2)+1);
+%! n=floor(lognrnd(8,2)+1);
 %! as=sprandn(m,n,0.3); af = full(as+1i*sprandn(as));
 %! bs=sprandn(m,n,0.3); bf = full(bs+1i*sprandn(bs));
 EOF
@@ -1149,7 +1226,7 @@ if $preset; then
   echo '%! bs=sparse(bf);' >> $TESTS
 else
   echo '# This has a small chance of failing to create a positive definite matrix' >> $TESTS
-  echo '%!test n=floor(lognormal_rnd(8,2)+1)' >> $TESTS
+  echo '%!test n=floor(lognrnd(8,2)+1)' >> $TESTS
   echo '%! bs = n*speye(n,n) + sprandn(n,n,0.3); bf = full(bs);' >> $TESTS
 fi
 
@@ -1173,8 +1250,8 @@ else
     cat >>$TESTS <<EOF
 %!test
 %! % generate m,n from 1 to <5000
-%! m=floor(lognormal_rnd(8,2)+1);
-%! n=floor(lognormal_rnd(8,2)+1);
+%! m=floor(lognrnd(8,2)+1);
+%! n=floor(lognrnd(8,2)+1);
 %! nz=ceil((m+n)/2);
 %! r=floor(rand(5,nz)*n)+1;
 %! c=floor(rand(5,nn)*m)+1;
@@ -1195,13 +1272,14 @@ else
     cat >>$TESTS <<EOF
 %!test
 %! % generate m,n from 1 to <5000
-%! m=floor(lognormal_rnd(8,2)+1);
-%! n=floor(lognormal_rnd(8,2)+1);
+%! m=floor(lognrnd(8,2)+1);
+%! n=floor(lognrnd(8,2)+1);
 %! as=sprandn(m,n,0.3); af = full(as+1i*sprandn(as));
 %! ridx = ceil(m*rand(1,ceil(rand*m))
 %! cidx = ceil(n*rand(1,ceil(rand*n))
 EOF
 fi
+gen_scalar_select_tests
 gen_select_tests
 echo '%!test af=real(af);' >> $TESTS
 gen_select_tests
